# acmenra_cv/inference/backends/__init__.py

import logging

from acmenra_cv.inference.backends.yolo_backend import YOLOBackend

logger = logging.getLogger(__name__)


__all__ = [
    'YOLOBackend'
]


__version__ = "0.2.0.7"