# acmenra_cv/inference/__init__.py

import logging

from acmenra_cv.inference.timing import Timing
from acmenra_cv.inference.result import Result
from acmenra_cv.inference.backend import Backend
from acmenra_cv.inference.backends import YOLOBackend


logger = logging.getLogger(__name__)


__all__ = [
    'Result',
    'Timing',
    'Backend',
    'YOLOBackend'
]


__version__ = "0.2.0.7"